@@ -5,7 +5,7 @@ use Lemonldap::NG::Common::UserAgent;
 use Lemonldap::NG::Common::Apache::Session::Generate::SHA256;
 use JSON qw(from_json to_json);
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 our @ISA = qw(Lemonldap::NG::Common::Apache::Session::Generate::SHA256);
 
@@ -120,7 +120,7 @@ sub getJson {
     my $resp = $self->ua->get( $self->base . $url, @_ );
     if ( $resp->is_success ) {
         my $res;
-        eval { $res = from_json( $resp->content ) };
+        eval { $res = from_json( $resp->content, { allow_nonref => 1 } ) };
         if ($@) {
             print STDERR "Unable to decode session: $@\n";
             return 0;
@@ -144,7 +144,7 @@ sub base {
 
 ## @method hashRef get(string id)
 # @param $id Apache::Session session ID.
-# @return User datas
+# @return User data
 sub get {
     my $self = shift;
     my $id   = shift;
@@ -165,7 +165,7 @@ sub get {
 
 ## @method hashRef newSession()
 # Build a new Apache::Session session.
-# @return User datas (just the session ID)
+# @return User data (just the session ID)
 sub newSession {
     my $self = shift;
     $self->generate unless ( $self->{data}->{_session_id} );
@@ -177,7 +177,7 @@ sub newSession {
     #my $resp = $self->ua->request($req);
     #if ( $resp->is_success ) {
     #    my $res;
-    #    eval { $res = from_json( $resp->content ) };
+    #    eval { $res = from_json( $resp->content, { allow_nonref => 1 } ) };
     #    if ( $@ or !$res->{result} ) {
     #        die "Unable to create session: bad REST response $@";
     #    }
@@ -200,7 +200,7 @@ sub newSession {
 }
 
 ## @method boolean save()
-# Save user datas if modified.
+# Save user data if modified.
 sub save {
     my $self = shift;
     return unless ( $self->{modified} );
@@ -229,7 +229,7 @@ sub save {
 
     if ( $resp->is_success ) {
         my $res;
-        eval { $res = from_json( $resp->content ) };
+        eval { $res = from_json( $resp->content, { allow_nonref => 1 } ) };
         if ($@) {
             die "Bad REST response: $@";
         }
@@ -317,7 +317,7 @@ Lemonldap::NG Web-SSO configuration. It is used by L<Lemonldap::NG::Handler>,
 L<Lemonldap::NG::Portal> and L<Lemonldap::NG::Manager>.
 
 Lemonldap::NG::Common::Apache::Session::REST used with
-L<Lemonldap::NG::Portal> provides the ability to acces to
+L<Lemonldap::NG::Portal> provides the ability to access to
 Lemonldap::NG sessions via REST: the portal act as a proxy to access to the
 real Apache::Session module (see HTML documentation for more)
 
@@ -352,7 +352,7 @@ L<LWP::UserAgent>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 =head1 DOWNLOAD
 
